@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2011 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-kajongg is free software you can redistribute it and/or modify
+Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation either version 2 of the License, or
 (at your option) any later version.
@@ -18,12 +18,11 @@ You should have received a copy of the GNU General Public License
 along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-The DBPasswordChecker is based on an example from the book
-Twisted Network Programming Essentials by Abe Fettig. Copyright 2006
-O'Reilly Media, Inc., ISBN 0-596-10032-9
 """
 
 from server import kajonggServer
+from util import checkMemory
 
 kajonggServer()
+checkMemory()
 # profileMe()
